# Snapstore api
[![Coverage Status](https://coveralls.io/repos/github/canonical-webteam/snapstore-api/badge.svg?branch=master)](https://coveralls.io/github/canonical-webteam/snapstore-api?branch=master)

This module provides functions in python to call the snapstore API. See API here: https://dashboard.snapcraft.io/docs/index.html

## Tests

`python tests.py`

## Todo

This project is in a beta status here is the list of issues to add to the project:

 - Env file
 - sentry configuration
 - Add documentation (in git wiki?)
 - CI integration (add `.travis.yaml`)
 - [not now] Add field filtering in functions, for now fields are filtered harcoded in the APIs urls
 - [not now] Custom User Agent in environment variable (?)
 - [not now] Add models (metrics/snaps/...)
 - publish to pip :)


 
